/*-------------------------------------------------------------------------+
| Copyright 2013 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.utils;

/**
 * Utility functions that deal with the underlying system.
 * 
 * @author ratiu, barner
 */
public class SystemUtils {

	/** Predicate if the current platform is Windows. */
	public static boolean isWindowsPlatform() {
		String osName = System.getProperty("os.name");
		return osName != null && osName.contains("Windows");
	}

	/** Predicate if the current platform is Linux. */
	public static boolean isLinuxPlatform() {
		String osName = System.getProperty("os.name");
		return osName != null && osName.contains("Linux");
	}

	/** Predicate if the current platform is Mac OS X. */
	public static boolean isMacOSXPlatform() {
		String osName = System.getProperty("os.name");
		return osName != null && osName.contains("Mac OS X.");
	}

	/** Predicate if the current <b>Java VM</b> architecture is 64 bit. */
	public static boolean isVm64BitArch() {
		String osArch = System.getProperty("os.arch");
		return osArch != null && osArch.contains("64");
	}

	/** Predicate if the current <b>OS</b> architecture is 64 bit. */
	public static boolean isOs64BitArch() {
		if(isWindowsPlatform()) {
			return System.getenv("ProgramFiles(x86)") != null;
		}

		return isVm64BitArch();
	}

	/**
	 * Converts an integer value representing an error into a string. If the exit code cannot be
	 * interpreted, then an empty string is returned.
	 */
	public static String interpretProcessExitValues(int exitValue) {
		if(!isWindowsPlatform()) {
			switch(exitValue) {
				case 126:
					return "Command not found";
				case 139:
					return "Segmentation fault";
			}
		}
		return "";
	}
}
